%define preversion 32patch1

Name:           ipe
Version:        6.0
Release:        0.32.pre%{preversion}%{?dist}
Summary:        Drawing editor for creating figures in PDF or PostScript formats

Group:          Applications/Publishing
#
# GPLv2, with an exception for the CGAL libraries.
License:        GPLv2+ with exceptions
#
URL:            http://tclab.kaist.ac.kr/ipe/
Source0:        http://luaforge.net/frs/download.php/4052/ipe-6.0pre%{preversion}-src.tar.gz

Patch1:         ipe-6.0pre30-gcc43.patch

# Fedora specific patch. It removes the runtime test of the Freetype
# library version. Freetype is supposed to bump its soname if the ABI is
# incompatible.
Patch10:        ipe-6.0pre28-no-freetype-version-check.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:  qt4-devel
BuildRequires:  desktop-file-utils
BuildRequires:  pkgconfig

# Tips found at https://bugzilla.redhat.com/bugzilla/show_bug.cgi?id=191589#c7
%global qtdir %(pkg-config --variable=prefix QtCore)

Requires:       tex(latex)
Requires:       urw-fonts
Requires:       xdg-utils

Provides:       ipe(api) = 5.99.%{preversion}pre
Provides:       ipetoipe = %{version}
Provides:       ipetopng = %{version}

%description
Ipe is a drawing editor for creating figures in PDF or (encapsulated)
Postscript format. It supports making small figures for inclusion into
LaTeX-documents as well as making multi-page PDF presentations that
can be shown on-line with a PDF viewer


%package devel
Summary: Development files and documentation for designing Ipelets
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}
Requires: qt4-devel
%description devel 
This packages contains the files necessary to develop Ipelets, which are
plugins for the Ipe editor.

%package doc
BuildArch: noarch
Summary: Documentation of Ipe
Group: Documentation
Requires: %{name} = %{version}-%{release}
%description doc
%{summary}.

%prep
%setup -n %{name}-%{version}pre%{preversion} -q
%patch1 -p1 -b '.gcc43'
%patch10 -p1 -b '.no-freetype-check'

# fix files permissions
find src -type f -exec chmod -x {} +

%build
export QTDIR=%{qtdir}

pushd src

# new file config.pri
rm config.pri
cat > config.pri <<'__EOF__'
IPEVERS =               %{version}
IPEBINDIR =             %{_bindir}
IPELIBDIR =             %{_libdir}
IPEHEADERDIR =          %{_includedir}
IPELETDIR =             %{_libdir}/ipe/%{version}/ipelets
IPELETPATH =            $${IPELETDIR}
IPEDOCDIR =             %{_datadir}/ipe/%{version}/doc
IPELANGDIR =            %{_datadir}/ipe/%{version}/languages
IPEMANDIR =             %{_mandir}/man1
IPEFONTMAP =            %{_datadir}/ipe/%{version}/fontmap.xml
IPEKEYSFILEDIR =        %{_datadir}/ipe/%{version}
IPEKEYSFILE =           $${IPEKEYSFILEDIR}/ipekeys.xml
IPEBROWSER =            xdg-open

FREETYPE_INCLUDE =      %{_includedir}/freetype2

CONFIG      -= qt
CONFIG      += warn_on release
DEFINES     += QT_NO_CAST_FROM_ASCII
__EOF__

# Call qmake.
$QTDIR/bin/qmake -Wlogic main.pro
# then make. (The CXX= option allows to change the compiler with rpm macros.)
make %{?_smp_mflags} CXX=%{__cxx}

popd 

# Create desktop file
cat > %{name}.desktop <<EOF
[Desktop Entry]
Type=Application
Encoding=UTF-8
Name=Ipe
Comment=The Ipe extensible drawing editor
Exec=ipe
Categories=Qt;Application;Graphics;
EOF

%install
rm -rf $RPM_BUILD_ROOT

pushd src
make INSTALL_ROOT=$RPM_BUILD_ROOT install
mkdir -p $RPM_BUILD_ROOT/usr/share/%{name}/%{version}
cp -f ../tetex-fontmap.xml $RPM_BUILD_ROOT/usr/share/%{name}/%{version}/fontmap.xml
popd

# Install desktop file
desktop-file-install --vendor fedora                            \
        --dir ${RPM_BUILD_ROOT}%{_datadir}/applications         \
        --add-category X-Fedora                                 \
        %{name}.desktop

# Remove backup files. qmake incorrectly installed the whole include/
# sub-directory.
rm -f ${RPM_BUILD_ROOT}%{_includedir}/*.gcc43

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%clean
rm -rf $RPM_BUILD_ROOT


%files
%defattr(-,root,root,-)
%doc readme.txt gpl.txt news.txt
%{_libdir}/libipe.so.1*
%{_libdir}/libipecanvas.so.1*
%{_libdir}/libipemodel.so.1*
%dir %{_libdir}/ipe
%dir %{_libdir}/ipe/%{version}
%dir %{_libdir}/ipe/%{version}/ipelets
%{_libdir}/ipe/%{version}/ipelets/*.so
%dir %{_datadir}/ipe
%dir %{_datadir}/ipe/%{version}
%{_datadir}/ipe/%{version}/*.xml
%{_bindir}/ipe
%{_bindir}/ipetoipe
%{_bindir}/ipetopng
#%{_bindir}/figtoipe
%{_mandir}/man1/ipe.1*
%{_mandir}/man1/ipetoipe.1*
%{_mandir}/man1/ipetopng.1*
#%{_mandir}/man1/figtoipe.1*
%{_datadir}/applications/*%{name}*.desktop

%files devel
%defattr(-,root,root,-)
%doc readme.txt gpl.txt news.txt
%{_includedir}/*.h
%{_libdir}/libipe.so
%{_libdir}/libipecanvas.so
%{_libdir}/libipemodel.so

%files doc
%defattr(-,root,root,-)
%doc readme.txt gpl.txt news.txt
%{_datadir}/ipe/%{version}/doc

%changelog
* Thu Aug 20 2009 Laurent Rineau <Laurent.Rineau__fedora@normalesup.org> - 6.0-0.32.pre32patch1%{?dist}
- New upstream release
- ipe5toxml no longer shipped
- Patch ipe-6.0pre30-pdftex1.40.patch is obsoleted

* Thu Aug 20 2009 Laurent Rineau <Laurent.Rineau__fedora@normalesup.org> - 6.0-0.31.pre30%{?dist}
- Requires tex(latex) instead of tetex (replaced by TeXLive)
- Add default attributes (error reported by rpmlint)

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 6.0-0.30.pre30
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Fri Feb 27 2009  <Laurent.Rineau__fedora@normalesup.org> - 6.0-0.29.pre30%{?dist}
- noarch ipe-doc

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 6.0-0.28.pre30
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed May 28 2008 Laurent Rineau <laurent.rineau__fedora@normalesup.org> - 6.0-0.27.pre30%{?dist}
- Add an upstream patch (Patch2), that should fix the incompatibility with
  pdfTeX-1.40 (TeXLive 2007), which is in Fedora 9.

* Tue Mar  4 2008 Laurent Rineau <laurent.rineau__fedora@normalesup.org> - 6.0-0.25.pre30%{?dist}
- Fix the URL: tag. (rebuild needed)

* Thu Feb 14 2008 Laurent Rineau <laurent.rineau__fedora@normalesup.org> - 6.0-0.24.pre30%{?dist}
- Fixes for gcc-4.3.

* Tue Dec  4 2007 Laurent Rineau <laurent.rineau__fedora@normalesup.org> - 6.0-0.23.pre30%{?dist}
- New upstream release.
- Patch "pre28-patch1" is now obsolete.
- Change the License: tag, to states that there is an exception for
  CGAL. The license is now "GPLv2+ with exceptions".

* Sat Nov 17 2007 Laurent Rineau <laurent.rineau__fedora@normalesup.org> - 6.0-0.22.pre28%{?dist}
- Make ipe use xdg-open (from package xdg-utils), instead of htmlview.

* Mon Sep 17 2007 Laurent Rineau <laurent.rineau__fedora@normalesup.org> - 6.0-0.21.pre28%{?dist}
- New upstream patch.

* Mon Aug 27 2007 Laurent Rineau <laurent.rineau__fedora@normalesup.org> - 6.0-0.20.pre28%{?dist}
- Change the URL, in Source0.

* Fri Aug 24 2007 Laurent Rineau <laurent.rineau__fedora@normalesup.org> - 6.0-0.19.pre28%{?dist}
- New patch: no longer check the version of freetype at runtime

* Fri Aug 24 2007 Laurent Rineau <laurent.rineau__fedora@normalesup.org> - 6.0-0.18.pre28%{?dist}
- New License: tag.
- Rebuild for F-8.

* Wed Jan 17 2007 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 6.0-0.17.pre28
- Provides ipe(api)

* Wed Jan 17 2007 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 6.0-0.15.pre28
- New upstream version.
- Patch4 is no longer needed.

* Thu Oct 05 2006 Christian Iseli <Christian.Iseli@licr.org> 6.0-0.14.pre27
 - rebuilt for unwind info generation, broken in gcc-4.1.1-21

* Tue Sep 26 2006 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 6.0-0.13.pre27
- Add BR: pkgconfig.

* Tue Sep 26 2006 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 6.0-0.12.pre27
- New upstream version.
- Remove Patch0 (ipe-6.0pre26-printf-size_t), fixed upstream.
- Remove Patch1 (ipe-6.0pre26-ipelet-pro_files), fixed upstream.
- Remove Patch2 (ipe-6.0pre26-initui.cpp), fixed upstream.
- Remove Patch3 (ipe-6.0pre26-libpath), fixed upstream.

* Thu Aug 31 2006 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 6.0-0.11.pre26
- New try to rebuild ipe-6.0pre26 for FC-6 mass rebuild.
- New patch: ipe_6.0pre26-qmake-defines.patch
  This patch changes the dealing of macros whose values should contain double
  quotes (needed under FC-6, which has qmake-4.2).
- New comments around the patches, to describe them.

* Mon Aug 28 2006 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 6.0-0.10.pre26
- Rebuild for FC-6.

* Thu Jul 20 2006 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 6.0-0.9.pre26
- Remove the BR: nas-devel, now that qt4 has stripped -laudio from its pkgconfig files.

* Thu Jul 20 2006 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 6.0-0.8.pre26
- New patch ipe_6.0pre26-libpath.patch, to be able to compile ipe even if another version is installed.
  This patch make use LIBPATH instead of explicit flags such as "-L../../build/lib/", in pro files.
- Modification of ipe_6.0pre26-ipelet-pro_files.patch, so that CONFIG+="plugin", and never CONFIG+="qt plugin", in ipelets pro files.
- Temporarely, add BuildRequires: nas-devel. qt4-devel should require it.

* Tue Jul  4 2006 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 6.0-0.7.pre26
- In %%files, use libipe.so.1*, instead of libipe.so.*
- Make sub-package %%{name}-doc depend on %%{name}

* Wed Jun 28 2006 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 6.0-0.6.pre26
- Added a patch, ipe_6.0pre26-initui.cpp.patch, to fix temporarely an upstream bug: QMenu aboutToshow() signal has a lowercase "a".

* Tue Jun 20 2006 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 6.0-0.5.pre26
- New patch ipe-6.0pre26-ipelet-pro_files.patch: fix the pro files of ipelets: the configshould be "plugin" instead of "dll".
- Cleanup of the %%files directives: do not own directories which are created by the main package in subpackages.

* Sun May 28 2006 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 6.0-0.4.pre26
- No longer hardcode qt4 prefix. Use pkg-config instead.

* Sun May 21 2006 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 6.0-0.3.pre26
- Added a desktop file for Ipe.

* Sun May 21 2006 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 6.0-0.2.pre26
- Fix directories ownership.
- ipelets/*.so are now in -devel.
- Creation of -doc subpackage.

* Tue May  9 2006 Laurent Rineau <laurent.rineau__fedora_extras@normalesup.org> - 6.0-0.1.pre26
- Initial revision.
